package com.fastbee.iot.service;

import java.util.List;
import com.fastbee.iot.domain.NgCardSwipeRecords;

/**
 * 刷卡记录Service接口
 *
 * @author kerwincui
 * @date 2024-12-30
 */
public interface INgCardSwipeRecordsService
{
    /**
     * 查询刷卡记录
     *
     * @param id 刷卡记录主键
     * @return 刷卡记录
     */
    public NgCardSwipeRecords selectNgCardSwipeRecordsById(Long id);

    /**
     * 查询用户刷卡记录列表根据卡号
     *
     * @param ngCardSwipeRecords 刷卡记录
     * @return 刷卡记录集合
     */
    public List<NgCardSwipeRecords> selectNgCardSwipeRecordsUserList(NgCardSwipeRecords ngCardSwipeRecords);

    /**
     * 查询刷卡记录列表
     *
     * @param ngCardSwipeRecords 刷卡记录
     * @return 刷卡记录集合
     */
    public List<NgCardSwipeRecords> selectNgCardSwipeRecordsList(NgCardSwipeRecords ngCardSwipeRecords);

    /**
     * 新增刷卡记录
     *
     * @param ngCardSwipeRecords 刷卡记录
     * @return 结果
     */
    public int insertNgCardSwipeRecords(NgCardSwipeRecords ngCardSwipeRecords);

    /**
     * 修改刷卡记录
     *
     * @param ngCardSwipeRecords 刷卡记录
     * @return 结果
     */
    public int updateNgCardSwipeRecords(NgCardSwipeRecords ngCardSwipeRecords);

    /**
     * 批量删除刷卡记录
     *
     * @param ids 需要删除的刷卡记录主键集合
     * @return 结果
     */
    public int deleteNgCardSwipeRecordsByIds(Long[] ids);

    /**
     * 删除刷卡记录信息
     *
     * @param id 刷卡记录主键
     * @return 结果
     */
    public int deleteNgCardSwipeRecordsById(Long id);
}
